==> keycloak-session-starter-1.2.3-sources.jar: digital/nedra/commons/starter/keycloak/session/config/SpringHttpSessionConfig.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.keycloak.session.config;

import java.util.concurrent.ConcurrentHashMap;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingClass;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.session.MapSessionRepository;
import org.springframework.session.SessionRepository;
import org.springframework.session.config.annotation.web.http.EnableSpringHttpSession;

@Configuration
@ConditionalOnMissingBean(SessionRepository.class)
@ConditionalOnMissingClass(
    "digital.nedra.commons.starter.keycloakpg.KeycloakPgScalingAutoConfiguration")
@EnableSpringHttpSession
public class SpringHttpSessionConfig {
  /**
   * Please use JdbcOAuth2AuthorizedClientService and Spring Sessions
   * in case when you have multiple backend instances.
   */
  @Bean
  public SessionRepository<?> sessionRepository() {
    return new MapSessionRepository(new ConcurrentHashMap<>());
  }
}

==> keycloak-session-starter-2.0.2-sources.jar: digital/nedra/commons/starter/keycloak/session/config/SpringHttpSessionConfig.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.keycloak.session.config;

import java.util.concurrent.ConcurrentHashMap;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingClass;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.session.MapSession;
import org.springframework.session.MapSessionRepository;
import org.springframework.session.SessionRepository;
import org.springframework.session.config.annotation.web.http.EnableSpringHttpSession;

@Configuration
@ConditionalOnMissingBean(SessionRepository.class)
@ConditionalOnMissingClass(
    "digital.nedra.commons.starter.keycloakpg.KeycloakPgScalingAutoConfiguration")
@EnableSpringHttpSession
public class SpringHttpSessionConfig {
  /**
   * Please use JdbcOAuth2AuthorizedClientService and Spring Sessions
   * in case when you have multiple backend instances.
   */
  @Bean
  public SessionRepository<MapSession> sessionRepository() {
    return new MapSessionRepository(new ConcurrentHashMap<>());
  }
}
